@@ -16,7 +16,7 @@
 #'
 #'   Multiple selection criteria can be applied by saving the output and
 #'   processing it through the function multiple times using different methods,
-#'   or alternatively via piping (`|>` or `%>%`). See Examples.
+#'   or alternatively via piping (`%>%` or `%>%`). See Examples.
 #'
 #'   *Note:* when choosing a `method`, keep in mind that to remain
 #'   mathematically consistent, `respR` outputs oxygen consumption (i.e.
@@ -298,8 +298,8 @@
 #'   The `overlap` method performs two operations:
 #'
 #'   First, regardless of the `n` value, any rate regressions which are
-#'   completely contained within another are removed (this is also the only
-#'   operation if `n = 1`).
+#'   completely contained within another are removed. This is also the only
+#'   operation if `n = 1`.
 #'
 #'   Secondly, for each regression in `$summary` starting from the bottom of the
 #'   summary table (usually the lowest ranked result, but this depends on the
@@ -408,39 +408,39 @@
 #' @examples
 #' \donttest{
 #' ## Object to filter
-#'  ar_obj <- inspect(intermittent.rd, plot = FALSE) |>
-#'    auto_rate(plot = FALSE) |>
+#'  ar_obj <- inspect(intermittent.rd, plot = FALSE) %>%
+#'    auto_rate(plot = FALSE) %>%
 #'    convert_rate(oxy.unit = "mg/L",
 #'                 time.unit = "s",
 #'                 output.unit = "mg/h",
-#'                 volume = 2.379) |>
+#'                 volume = 2.379) %>%
 #'    summary()
 #'
 #'  ## Select only negative rates
-#'  ar_subs_neg <- select_rate(ar_obj, method = "negative") |>
+#'  ar_subs_neg <- select_rate(ar_obj, method = "negative") %>%
 #'    summary()
 #'
 #'  ## Select only rates over 1000 seconds duration
-#'  ar_subs_dur <- select_rate(ar_obj, method = "duration", n = c(1000, Inf)) |>
+#'  ar_subs_dur <- select_rate(ar_obj, method = "duration", n = c(1000, Inf)) %>%
 #'    summary()
 #'
 #'  ## Reorder rates sequentially (i.e. by starting row)
-#'  ar_subs_dur <- select_rate(ar_obj, method = "row") |>
+#'  ar_subs_dur <- select_rate(ar_obj, method = "row") %>%
 #'    summary()
 #'
 #'  ## Select rates with r-squared higher than 0.99,
 #'  ## then select the lowest 10th percentile of the remaining rates,
 #'  ## then take the mean of those
-#'  inspect(squid.rd, plot = FALSE) |>
+#'  inspect(squid.rd, plot = FALSE) %>%
 #'    auto_rate(method = "linear",
-#'              plot = FALSE) |>
+#'              plot = FALSE) %>%
 #'    convert_rate(oxy.unit = "mg/L",
 #'                 time.unit = "s",
 #'                 output.unit = "mg/h",
-#'                 volume = 2.379) |>
-#'    summary() |>
-#'    select_rate(method = "rsq", n = c(0.99, 1)) |>
-#'    select_rate(method = "lowest_percentile", n = 0.1) |>
+#'                 volume = 2.379) %>%
+#'    summary() %>%
+#'    select_rate(method = "rsq", n = c(0.99, 1)) %>%
+#'    select_rate(method = "lowest_percentile", n = 0.1) %>%
 #'    mean()
 #'    }
 
@@ -983,15 +983,22 @@ select_rate <- function(x, method = NULL, n = NULL){
       keep <- c(keep1, keep2)
       # otherwise do this possibly very slow loop
     } else {
-      message("select_rate: For 'row_omit' method, selecting multiple 'n' inputs can be VERY SLOW. \nIf possible, specifying a range using lower and upper values is much faster.")
-      remove <- c() # empty obj for loop results
+      message("select_rate: For 'row_omit' method using multiple 'n' inputs can be VERY SLOW. A range of lower and upper values is MUCH faster.")
+        # progress bar object
+        progress <- txtProgressBar(min = 0,               # Minimum value of the progress bar
+                             max = length(n_order), # Maximum value of the progress bar
+                             style = 3,    # Progress bar style (also available style = 1 and style = 2)
+                             width = NA,   # Progress bar width. Defaults to getOption("width")
+                             char = "=")
       # for each n, go through summary table by row
       # if it occurs between row and endrow then that row of summary gets removed
+      remove <- c() # empty obj for loop results
       for(i in n_order){
         remove_i <- which(apply(x$summary, 1, function(z) any(i %in% z[7]:z[8])))
         remove <- sort(unique(c(remove, remove_i)))
-        progress.bar(which(i == n_order), length(n_order), "select_rate: 'row_omit' progress")
+        setTxtProgressBar(progress, which(i == n_order))
       }
+      close(progress)
       cat("\n")
       # if nothing to remove, above outputs integer(0), so this is for that...
       if(length(remove) > 0) keep <- (1:nrow(x$summary))[-remove] else
@@ -1045,14 +1052,20 @@ select_rate <- function(x, method = NULL, n = NULL){
     } else {
       message("select_rate: For 'time_omit' method, selecting multiple 'n' inputs can be VERY SLOW. \nIf possible, specifying a range using lower and upper values is much faster.")
 
+      # progress bar object
+      progress <- txtProgressBar(min = 0,               # Minimum value of the progress bar
+                           max = length(n_order), # Maximum value of the progress bar
+                           style = 3,    # Progress bar style (also available style = 1 and style = 2)
+                           width = NA,   # Progress bar width. Defaults to getOption("width")
+                           char = "=")
       remove <- c() # empty obj for loop results
-
       for(i in n_order){
         remove_i <- which(apply(x$summary, 1, function(z)
           data.table::between(i, z[9], z[10], incbounds = TRUE)))
         remove <- sort(unique(c(remove, remove_i)))
-        progress.bar(which(i == n_order), length(n_order), "select_rate: 'time_omit' progress")
+        setTxtProgressBar(progress, which(i == n_order))
       }
+      close(progress)
       cat("\n")
       # if nothing to remove, above outputs integer(0), so this is for that...
       if(length(remove) > 0) keep <- (1:nrow(x$summary))[-remove] else
